@@ -4,14 +4,14 @@ require 'rmagick'
 # uses a 3-image animation to show each step of the
 # process
 
-Rows = 60
-Cols = 250
-Text = 'Ruby rocks!'
+ROWS = 60
+COLS = 250
+TEXT = 'Ruby rocks!'
 
 # This imagelist will contain the animation frames
 anim = Magick::ImageList.new
 
-ex = Magick::Image.new(Cols, Rows)
+ex = Magick::Image.new(COLS, ROWS)
 
 # Create a Draw object to draw the text with. Most of the text
 # attributes are shared between the shadow and the foreground.
@@ -25,7 +25,7 @@ text.stroke = 'transparent'
 
 # Draw the shadow text first. The color is a very light gray.
 # Position the text to the right and down.
-text.annotate(ex, 0, 0, 2, 2, Text) do |options|
+text.annotate(ex, 0, 0, 2, 2, TEXT) do |options|
   options.fill = 'gray60'
 end
 
@@ -38,7 +38,7 @@ anim << ex.copy
 
 # Add the foreground text in solid black. Position it
 # to the left and up from the shadow text.
-text.annotate(ex, 0, 0, -1, -1, Text) do |options|
+text.annotate(ex, 0, 0, -1, -1, TEXT) do |options|
   options.fill = 'maroon'
 end
 
