@@ -2,20 +2,20 @@ require 'rmagick'
 
 # Demonstrate the HatchFill class
 
-Cols = 300
-Rows = 100
+COLS = 300
+ROWS = 100
 
-Background = 'white'
-Foreground = 'LightCyan2'
+BACKGROUND = 'white'
+FOREGROUND = 'LightCyan2'
 
-fill = Magick::HatchFill.new(Background, Foreground)
+fill = Magick::HatchFill.new(BACKGROUND, FOREGROUND)
 img = Magick::ImageList.new
-img.new_image(Cols, Rows, fill)
+img.new_image(COLS, ROWS, fill)
 
 # Annotate the filled image with the code that created the fill.
 
 ann = Magick::Draw.new
-ann.annotate(img, 0, 0, 0, 0, "HatchFill.new('#{Background}', '#{Foreground}')") do |options|
+ann.annotate(img, 0, 0, 0, 0, "HatchFill.new('#{BACKGROUND}', '#{FOREGROUND}')") do |options|
   options.gravity = Magick::CenterGravity
   options.fill = 'black'
   options.stroke = 'transparent'
