@@ -2,7 +2,7 @@ require 'rmagick'
 
 # Demonstrate the annotate method
 
-Text = 'RMagick'
+TEXT = 'RMagick'
 
 granite = Magick::ImageList.new('granite:')
 canvas = Magick::ImageList.new
@@ -12,15 +12,15 @@ text = Magick::Draw.new
 text.pointsize = 52
 text.gravity = Magick::CenterGravity
 
-text.annotate(canvas, 0, 0, 2, 2, Text) do |options|
+text.annotate(canvas, 0, 0, 2, 2, TEXT) do |options|
   options.fill = 'gray83'
 end
 
-text.annotate(canvas, 0, 0, -1.5, -1.5, Text) do |options|
+text.annotate(canvas, 0, 0, -1.5, -1.5, TEXT) do |options|
   options.fill = 'gray40'
 end
 
-text.annotate(canvas, 0, 0, 0, 0, Text) do |options|
+text.annotate(canvas, 0, 0, 0, 0, TEXT) do |options|
   options.fill = 'darkred'
 end
 
