@@ -2,7 +2,6 @@
 # an animated MIFF file showing a rotating text string.
 
 require 'rmagick'
-include Magick
 
 puts <<~END_INFO
   Demonstrate the rotation= attribute in the Draw class
@@ -10,23 +9,23 @@ puts <<~END_INFO
   by entering the command: animate rotating_text.miff
 END_INFO
 
-text = Draw.new
+text = Magick::Draw.new
 text.pointsize = 28
-text.font_weight = BoldWeight
-text.font_style = ItalicStyle
-text.gravity = CenterGravity
+text.font_weight = Magick::BoldWeight
+text.font_style = Magick::ItalicStyle
+text.gravity = Magick::CenterGravity
 text.fill = 'white'
 
 # Let's make it interesting. Composite the
 # rotated text over a gradient fill background.
-fill = GradientFill.new(100, 100, 100, 100, 'yellow', 'red')
-bg = Image.new(200, 200, fill)
+fill = Magick::GradientFill.new(100, 100, 100, 100, 'yellow', 'red')
+bg = Magick::Image.new(200, 200, fill)
 
 # The "none" color is transparent.
-fg = Image.new(bg.columns, bg.rows) { |options| options.background_color = 'none' }
+fg = Magick::Image.new(bg.columns, bg.rows) { |options| options.background_color = 'none' }
 
 # Here's where we'll collect the individual frames.
-animation = ImageList.new
+animation = Magick::ImageList.new
 
 0.step(345, 15) do |degrees|
   frame = fg.copy
@@ -34,7 +33,7 @@ animation = ImageList.new
     options.rotation = degrees
   end
   # Composite the text over the gradient filled background frame.
-  animation << bg.composite(frame, CenterGravity, DisplaceCompositeOp)
+  animation << bg.composite(frame, Magick::CenterGravity, Magick::DisplaceCompositeOp)
 end
 
 animation.delay = 8
