@@ -10,9 +10,6 @@ module RMagick
     RMAGICK_VERS = ::Magick::VERSION
     MIN_RUBY_VERS = ::Magick::MIN_RUBY_VERSION
 
-    # ImageMagick 6.7 package
-    IM6_7_PACKAGES = ['ImageMagick'].freeze
-
     # ImageMagick 6.8+ packages
     IM6_PACKAGES = %w[
       ImageMagick-6.Q64HDRI
@@ -23,6 +20,7 @@ module RMagick
       ImageMagick-6.Q32
       ImageMagick-6.Q16
       ImageMagick-6.Q8
+      ImageMagick-6
     ].freeze
 
     # ImageMagick 7 packages
@@ -35,6 +33,7 @@ module RMagick
       ImageMagick-7.Q32
       ImageMagick-7.Q16
       ImageMagick-7.Q8
+      ImageMagick-7
     ].freeze
 
     attr_reader :headers
@@ -42,6 +41,8 @@ module RMagick
     def initialize
       @stdout = $stdout.dup
 
+      exit_failure("No longer support MSWIN environment.") if RUBY_PLATFORM.include?('mswin')
+
       setup_pkg_config_path
       assert_can_compile!
       configure_compile_options
@@ -49,19 +50,20 @@ module RMagick
     end
 
     def setup_pkg_config_path
-      return if RUBY_PLATFORM =~ /mswin|mingw/
+      return if RUBY_PLATFORM.include?('mingw')
 
       if find_executable('brew')
-        pkg_config_path = "#{`brew --prefix imagemagick@6`.strip}/lib/pkgconfig"
+        append_pkg_config_path("#{`brew --prefix imagemagick`.strip}/lib/pkgconfig")
+        append_pkg_config_path("#{`brew --prefix imagemagick@6`.strip}/lib/pkgconfig")
       elsif find_executable('pacman')
-        pkg_config_path = '/usr/lib/imagemagick6/pkgconfig'
-      else
-        return
+        append_pkg_config_path('/usr/lib/imagemagick6/pkgconfig')
       end
+    end
 
+    def append_pkg_config_path(path)
       pkg_config_paths = ENV['PKG_CONFIG_PATH'].to_s.split(':')
-      if File.exist?(pkg_config_path) && !pkg_config_paths.include?(pkg_config_path)
-        ENV['PKG_CONFIG_PATH'] = [ENV['PKG_CONFIG_PATH'], pkg_config_path].compact.join(':')
+      if File.exist?(path) && !pkg_config_paths.include?(path)
+        ENV['PKG_CONFIG_PATH'] = [ENV['PKG_CONFIG_PATH'], path].compact.join(':')
       end
     end
 
@@ -77,7 +79,7 @@ module RMagick
     end
 
     def configure_headers
-      @headers = %w[assert.h ctype.h stdio.h stdlib.h math.h time.h sys/types.h]
+      @headers = %w[assert.h ctype.h stdio.h stdlib.h math.h time.h sys/types.h ruby.h ruby/io.h]
 
       if have_header('MagickCore/MagickCore.h')
         headers << 'MagickCore/MagickCore.h'
@@ -86,11 +88,25 @@ module RMagick
       else
         exit_failure "Can't install RMagick #{RMAGICK_VERS}. Can't find magick/MagickCore.h."
       end
+
+      if have_header('malloc.h')
+        headers << 'malloc.h'
+      elsif have_header('malloc/malloc.h')
+        headers << 'malloc/malloc.h'
+      end
     end
 
     def configure_compile_options
       # Magick-config is not available on Windows
-      if RUBY_PLATFORM !~ /mswin|mingw/
+      if RUBY_PLATFORM.include?('mingw') # mingw
+
+        dir_paths = search_paths_for_windows
+        $CPPFLAGS += %( -I"#{dir_paths[:include]}")
+        $CPPFLAGS += ' -x c++ -std=c++11 -Wno-register'
+        $LDFLAGS += %( -L"#{dir_paths[:root]}" -lucrt)
+        $LDFLAGS += (im_version_at_least?('7.0.0') ? ' -lCORE_RL_MagickCore_' : ' -lCORE_RL_magick_')
+
+      else
 
         check_multiple_imagemagick_versions
         check_partial_imagemagick_versions
@@ -103,7 +119,8 @@ module RMagick
 
         # Save flags
         $CPPFLAGS   += " #{ENV['CPPFLAGS']} " + PKGConfig.cflags($magick_package).chomp
-        $LOCAL_LIBS += " #{ENV['LIBS']} "     + PKGConfig.libs($magick_package).chomp
+        $CPPFLAGS   += ' -x c++ -std=c++11 -Wno-register'
+        $LOCAL_LIBS += " #{ENV['LIBS']} " + PKGConfig.libs($magick_package).chomp
         $LDFLAGS    += " #{ldflags} #{rpath}"
 
         unless try_link("int main() { }")
@@ -111,33 +128,10 @@ module RMagick
           $LDFLAGS = "#{original_ldflags} #{ldflags}"
         end
 
-        configure_archflags_for_osx($magick_package) if RUBY_PLATFORM =~ /darwin/ # osx
-
-      elsif RUBY_PLATFORM =~ /mingw/ # mingw
-
-        dir_paths = search_paths_for_library_for_windows
-        $CPPFLAGS += %( -I"#{dir_paths[:include]}")
-        $LDFLAGS += %( -L"#{dir_paths[:lib]}")
-        $LDFLAGS << ' -lucrt' if Gem::Version.new(RUBY_VERSION) >= Gem::Version.new('2.4.0')
-
-        have_library(im_version_at_least?('7.0.0') ? 'CORE_RL_MagickCore_' : 'CORE_RL_magick_')
-
-      else # mswin
-
-        dir_paths = search_paths_for_library_for_windows
-        $CPPFLAGS << %( -I"#{dir_paths[:include]}")
-        $LDFLAGS << %( -libpath:"#{dir_paths[:lib]}")
-        $LDFLAGS << ' -libpath:ucrt' if Gem::Version.new(RUBY_VERSION) >= Gem::Version.new('2.4.0')
-
-        $LOCAL_LIBS += ' ' + (im_version_at_least?('7.0.0') ? 'CORE_RL_MagickCore_.lib' : 'CORE_RL_magick_.lib')
+        configure_archflags_for_osx($magick_package) if RUBY_PLATFORM.include?('darwin') # osx
 
       end
-
-      $CPPFLAGS << if have_macro('__GNUC__')
-                     ' -std=gnu99 -Wno-void-pointer-to-int-cast -Wno-void-pointer-to-enum-cast -Wno-pointer-to-int-cast'
-                   else
-                     ' -std=c99'
-                   end
+      $CPPFLAGS += ' $(optflags) $(debugflags) -fomit-frame-pointer'
     end
 
     def exit_failure(msg)
@@ -174,11 +168,6 @@ module RMagick
     def determine_imagemagick_package
       packages = [installed_im7_packages, installed_im6_packages].flatten
 
-      if packages.empty?
-        # ImageMagick 6.7 does not have package file like ImageMagick-6.Q16.pc
-        packages = detect_imagemagick_packages(IM6_7_PACKAGES)
-      end
-
       if packages.empty?
         exit_failure "Can't install RMagick #{RMAGICK_VERS}. Can't find ImageMagick with pkg-config\n"
       end
@@ -262,10 +251,10 @@ module RMagick
     # issue #169
     # set ARCHFLAGS appropriately for OSX
     def configure_archflags_for_osx(magick_package)
-      return unless PKGConfig.libs_only_L(magick_package).match(%r{-L(.+)/lib})
+      return unless PKGConfig.libs_only_L(magick_package) =~ %r{-L(.+)/lib}
 
       imagemagick_dir = Regexp.last_match(1)
-      command = Dir.glob(File.join(imagemagick_dir, "bin/*")).select { |file| File.executable? file }.first
+      command = Dir.glob(File.join(imagemagick_dir, "bin/*")).find { |file| File.executable? file }
       fileinfo = `file #{command}`
 
       # default ARCHFLAGS
@@ -279,36 +268,33 @@ module RMagick
       $ARCH_FLAG = archflags.join(' ') unless archflags.empty?
     end
 
-    def search_paths_for_library_for_windows
+    def search_paths_for_windows
       msg = 'searching PATH for the ImageMagick library...'
       Logging.message msg
       message msg + "\n"
 
-      found_lib = false
+      found = false
       dir_paths = {}
 
       paths = ENV['PATH'].split(File::PATH_SEPARATOR)
       paths.each do |dir|
-        lib = File.join(dir, 'lib')
-        lib_file = File.join(lib, im_version_at_least?('7.0.0') ? 'CORE_RL_MagickCore_.lib' : 'CORE_RL_magick_.lib')
-        next unless File.exist?(lib_file)
+        dll = File.join(dir, im_version_at_least?('7.0.0') ? 'CORE_RL_MagickCore_.dll' : 'CORE_RL_magick_.dll')
+        next unless File.exist?(dll)
 
         dir_paths[:include] = File.join(dir, 'include')
-        dir_paths[:lib] = lib
+        dir_paths[:root] = dir
 
-        found_lib = true
+        found = true
         break
       end
 
-      return dir_paths if found_lib
+      return dir_paths if found
 
       exit_failure <<~END_MINGW
         Can't install RMagick #{RMAGICK_VERS}.
         Can't find the ImageMagick library.
-        Retry with '--with-opt-dir' option.
-        Usage: gem install rmagick -- '--with-opt-dir=\"[path to ImageMagick]\"'
-        e.g.
-          gem install rmagick -- '--with-opt-dir=\"C:\\Program Files\\ImageMagick-6.9.1-Q16\"'
+
+        Please check PATH environment variable for ImageMagick installation path.
       END_MINGW
     end
 
@@ -316,9 +302,9 @@ module RMagick
       assert_minimum_ruby_version!
       assert_has_dev_libs!
 
-      # Check for compiler. Extract first word so ENV['CC'] can be a program name with arguments.
-      cc = (ENV['CC'] || RbConfig::CONFIG['CC'] || 'gcc').split(' ').first
-      exit_failure "No C compiler found in ${ENV['PATH']}. See mkmf.log for details." unless find_executable(cc)
+      # Check for compiler. Extract first word so ENV['CXX'] can be a program name with arguments.
+      cxx = (ENV['CXX'] || RbConfig::CONFIG['CXX'] || 'g++').split.first
+      exit_failure "No C++ compiler found in ${ENV['PATH']}. See mkmf.log for details." unless find_executable(cxx)
     end
 
     def assert_minimum_ruby_version!
@@ -336,17 +322,17 @@ module RMagick
         Check the mkmf.log file for more detailed information.
       END_FAILURE
 
-      if RUBY_PLATFORM !~ /mswin|mingw/
+      if RUBY_PLATFORM.include?('mingw')
+        `#{magick_command} -version` =~ /Version: ImageMagick (\d+\.\d+\.\d+)-+\d+ /
+        $magick_version = Regexp.last_match(1)
+        exit_failure failure_message unless $magick_version
+      else
         unless PKGConfig.libs('MagickCore')[/\bl\s*(MagickCore|Magick)6?\b/]
           exit_failure failure_message
         end
 
         $magick_package = determine_imagemagick_package
         $magick_version = PKGConfig.modversion($magick_package)[/^(\d+\.\d+\.\d+)/]
-      else
-        `#{magick_command} -version` =~ /Version: ImageMagick (\d+\.\d+\.\d+)-+\d+ /
-        $magick_version = Regexp.last_match(1)
-        exit_failure failure_message unless $magick_version
       end
 
       # Ensure minimum ImageMagick version
@@ -360,8 +346,7 @@ module RMagick
 
     def create_header_file
       ruby_api = [
-        'rb_gc_adjust_memory_usage', # Ruby 2.4.0
-        'rb_gc_mark_movable' # Ruby 2.7.0
+        'rb_io_path' # Ruby 3.2.0
       ]
       memory_api = %w[
         posix_memalign
@@ -380,15 +365,10 @@ module RMagick
         have_func(func, headers)
       end
 
-      unless have_header('malloc.h')
-        have_header('malloc/malloc.h')
-      end
-
       # Miscellaneous constants
       $defs.push("-DRUBY_VERSION_STRING=\"ruby #{RUBY_VERSION}\"")
       $defs.push("-DRMAGICK_VERSION_STRING=\"RMagick #{RMAGICK_VERS}\"")
 
-      $defs.push('-DIMAGEMAGICK_GREATER_THAN_EQUAL_6_8_9=1') if im_version_at_least?('6.8.9')
       $defs.push('-DIMAGEMAGICK_GREATER_THAN_EQUAL_6_9_0=1') if im_version_at_least?('6.9.0')
       $defs.push('-DIMAGEMAGICK_GREATER_THAN_EQUAL_6_9_10=1') if im_version_at_least?('6.9.10')
       $defs.push('-DIMAGEMAGICK_7=1') if im_version_at_least?('7.0.0')
@@ -408,6 +388,22 @@ module RMagick
       print_summary
     end
 
+    def create_compile_flags_txt
+      cppflags = $CPPFLAGS.split
+      include_flags = cppflags.select { |flag| flag.start_with?('-I') }
+      define_flags = cppflags.select { |flag| flag.start_with?('-D') } + $defs
+
+      File.open('compile_flags.txt', 'w') do |f|
+        include_flags.each { |flag| f.puts(flag) }
+        f.puts "-I#{Dir.pwd}"
+        f.puts "-I#{RbConfig::CONFIG['rubyhdrdir']}"
+        f.puts "-I#{RbConfig::CONFIG['rubyhdrdir']}/ruby/backward"
+        f.puts "-I#{RbConfig::CONFIG['rubyarchhdrdir']}"
+        f.puts "-std=c++11"
+        define_flags.each { |flag| f.puts(flag) }
+      end
+    end
+
     def magick_command
       @magick_command ||= if find_executable('magick')
                             'magick'
@@ -446,3 +442,4 @@ at_exit do
   message msg + "\n"
 end
 extconf.create_makefile_file
+extconf.create_compile_flags_txt
