@@ -91,12 +91,15 @@ RSpec.describe Magick do
           r.take
         end.not_to raise_error
 
-        expect do
-          r = Ractor.new do
-            Magick.formats # rubocop:disable RSpec/DescribedClass
-          end
-          r.take
-        end.not_to raise_error
+        unless RUBY_PLATFORM.include?('mingw')
+          # Skip because it causes "`init_formats': unable to register image format 'DMR'" error on Windows
+          expect do
+            r = Ractor.new do
+              Magick.formats # rubocop:disable RSpec/DescribedClass
+            end
+            r.take
+          end.not_to raise_error
+        end
       end
     end
   end
