@@ -14,6 +14,11 @@ RSpec.describe Magick::Draw, '#fill_opacity' do
     draw.circle(10, '20.5', 30, 40.5)
     expect { draw.draw(image) }.not_to raise_error
 
+    draw = described_class.new
+    draw.fill_opacity(1/4r)
+    expect(draw.inspect).to eq('fill-opacity 0.25')
+    expect { draw.draw(image) }.not_to raise_error
+
     expect { draw.fill_opacity(0.0) }.not_to raise_error
     expect { draw.fill_opacity(1.0) }.not_to raise_error
     expect { draw.fill_opacity('0.0') }.not_to raise_error
@@ -25,5 +30,6 @@ RSpec.describe Magick::Draw, '#fill_opacity' do
     expect { draw.fill_opacity('-0.01') }.to raise_error(ArgumentError)
     expect { draw.fill_opacity('1.01') }.to raise_error(ArgumentError)
     expect { draw.fill_opacity('xxx') }.to raise_error(ArgumentError)
+    expect { draw.fill_opacity('%20') }.to raise_error(ArgumentError)
   end
 end
