@@ -7,6 +7,6 @@ RSpec.describe Magick::Image, "#border" do
     result = image.border(2, 2, 'red')
     expect(result).to be_instance_of(described_class)
     image.freeze
-    expect { image.border!(2, 2, 'red') }.to raise_error(FreezeError)
+    expect { image.border!(2, 2, 'red') }.to raise_error(FrozenError)
   end
 end
