@@ -22,9 +22,10 @@ RSpec.describe Magick::Image, "#changed?" do
   it "still returns true after it has been persisted" do
     image = described_class.read(FLOWER_HAT).first
 
-    image.import_pixels(0, 0, 1, 1, "RGB", [45, 98, 156])
-    image.write("./tmp/test_changed_predicate.jpg")
-
-    expect(image.changed?).to be(true)
+    Dir.mktmpdir do |tmp|
+      image.import_pixels(0, 0, 1, 1, "RGB", [45, 98, 156])
+      image.write("#{tmp}/test_changed_predicate.jpg")
+      expect(image.changed?).to be(true)
+    end
   end
 end
