@@ -5,6 +5,6 @@ describe Magick::Image::PolaroidOptions, "#border_color" do
     expect { options.border_color = "gray50" }.not_to raise_error
 
     options.freeze
-    expect { options.border_color = "gray50" }.to raise_error(FreezeError)
+    expect { options.border_color = "gray50" }.to raise_error(FrozenError)
   end
 end
