@@ -10,7 +10,7 @@ RSpec.describe Magick::ImageList, "#mosaic" do
   it "raises an error when images is not set" do
     image_list = described_class.new
 
-    image_list.instance_variable_set("@images", nil)
+    image_list.instance_variable_set(:@images, nil)
     expect { image_list.mosaic }.to raise_error(Magick::ImageMagickError)
   end
 end
