@@ -6,7 +6,7 @@ RSpec.describe Magick::ImageList, '#reject' do
     cur = image_list.cur_image
     image_list2 = image_list
 
-    result = image_list.reject { |image| File.basename(image.filename) =~ /Button_9/ }
+    result = image_list.reject { |image| File.basename(image.filename).include?('Button_9') }
     expect(result.length).to eq(9)
     expect(result).to be_instance_of(described_class)
     expect(result.cur_image).to be(cur)
@@ -15,7 +15,7 @@ RSpec.describe Magick::ImageList, '#reject' do
     expect(image_list.cur_image).to be(cur)
 
     # Omit current image from result image_list - result cur_image s/b last image
-    result = image_list.reject { |image| File.basename(image.filename) =~ /Button_7/ }
+    result = image_list.reject { |image| File.basename(image.filename).include?('Button_7') }
     expect(result.length).to eq(9)
     expect(result.cur_image).to be(result[-1])
     expect(image_list.cur_image).to be(cur)
