@@ -14,11 +14,11 @@ RSpec.describe Magick::ImageList, '#<=>' do
     image_list2 << image_list1[9]
     expect(image_list2).not_to eq(image_list1)
 
-    expect { image_list1 <=> 2 }.to raise_error(TypeError)
+    expect(image_list1 <=> 2).to be(nil)
     image_list2 = described_class.new
     image_list3 = described_class.new
-    expect { image_list2 <=> image_list1 }.to raise_error(TypeError)
-    expect { image_list1 <=> image_list2 }.to raise_error(TypeError)
-    expect { image_list3 <=> image_list2 }.not_to raise_error
+    expect(image_list2 <=> image_list1).to be(nil)
+    expect(image_list1 <=> image_list2).to be(nil)
+    expect(image_list3 <=> image_list2).to be 0
   end
 end
