@@ -6,7 +6,7 @@ RSpec.describe Magick::KernelInfo, '#scale' do
       expect(kernel.scale(1.0, flag)).to be(nil)
       expect(kernel.scale(42, flag)).to be(nil)
     end
-    expect { kernel.scale(42, 'x') }.to raise_error(ArgumentError)
-    expect { kernel.scale(42, Magick::BoldWeight) }.to raise_error(ArgumentError)
+    expect { kernel.scale(42, 'x') }.to raise_error(TypeError)
+    expect { kernel.scale(42, Magick::BoldWeight) }.to raise_error(TypeError)
   end
 end
